@@ -31,12 +31,6 @@
 (ert-deftest py-ert-shell-map-test ()
   (should (boundp 'py-shell-map)))
 
-(ert-deftest py-ert--timer-test ()
-  (should (boundp 'py--timer)))
-
-(ert-deftest py-ert--timer-delay-test ()
-  (should (boundp 'py--timer-delay)))
-
 (ert-deftest py-ert-eldoc-string-code-test ()
   (should (boundp 'py-eldoc-string-code)))
 
@@ -490,9 +484,6 @@
 (ert-deftest py-ert-shell-toggle-2-test ()
   (should (boundp 'py-shell-toggle-2)))
 
-(ert-deftest py-ert-shell-unfontify-p-test ()
-  (should (boundp 'py-shell-unfontify-p)))
-
 (ert-deftest py-ert-smart-indentation-test ()
   (should (boundp 'py-smart-indentation)))
 
@@ -568,9 +559,6 @@
 (ert-deftest py-ert-block-or-clause-re-test ()
   (should (boundp 'py-block-or-clause-re)))
 
-(ert-deftest py-ert-bol-forms-last-indent-test ()
-  (should (boundp 'py-bol-forms-last-indent)))
-
 (ert-deftest py-ert-buffer-name-test ()
   (should (boundp 'py-buffer-name)))
 
@@ -658,9 +646,6 @@
 (ert-deftest py-ert-force-local-shell-p-test ()
   (should (boundp 'py-force-local-shell-p)))
 
-(ert-deftest py-ert-ignore-result-p-test ()
-  (should (boundp 'py-ignore-result-p)))
-
 (ert-deftest py-ert-import-from-face-test ()
   (should (boundp 'py-import-from-face)))
 
